@@ -20,11 +20,14 @@
 
 #define TEXT_ABOUT "<qt><br><br><p><i><b>qtWallet</b></i>, v.1.0</p>"\
 			"<p>Developed by <b>nowheremanmail@gmail.com</b></p>"\
-			"<br>"\
+			"<p>Icons by http://pixelmixer.ru/</p>"\
 			"<p>if you think that qtWallet is useful for you, please</p>"\
 			"<a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted\">DONATE</a></qt>"
 
-#define SOFT_VERSION 1
+#define SOFT_VERSION 2
+#define PASS1 "developped by nowhereman"
+#define PASS2 "nowheremanmail@gmail.com Lorem Ipsum és un text de farciment usat per la indústria de la tipografia i la impremta. Lorem Ipsum ha estat el text estàndard de la indústria des de l'any 1500, quan un impressor desconegut va fer servir una galerada de text i la va mesclar per crear un llibre de mostres tipogràfiques. No només ha sobreviscut cinc segles, sinó que ha fet el salt cap a la creació de tipus de lletra electrònics, romanent essencialment sense canvis. Es va popularitzar l'any 1960 amb el llançament de fulls Letraset que contenien passatges de Lorem Ipsum, i més recentment amb programari d'autoedició com Aldus Pagemaker que inclou versions de Lorem Ipsum."
+#define SHA1_LEN 64
 /*
 
 Format 	Dimension 	Usage
